@@ -106,7 +106,8 @@ struct _ChartStack
 	gchar	    *budget_title;
 	gchar	    *result_title;
 
-	gboolean		minor;
+	gboolean	minor;
+	guint32		kcur;
 	gdouble		minor_rate;
 	gchar		*minor_symbol;
 
@@ -176,6 +177,7 @@ void ui_chart_stack_set_barw(ChartStack * chart, gdouble barw);
 void ui_chart_stack_show_minor(ChartStack * chart, gboolean minor);
 
 void ui_chart_stack_set_minor_prefs(ChartStack * chart, gdouble rate, gchar *symbol);
+void ui_chart_stack_set_currency(ChartStack * chart, guint32 kcur);
 
 #ifdef __cplusplus
 }
