@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2017 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -65,7 +65,7 @@ struct ui_flt_manage_data
 };
 
 
-gint ui_flt_manage_dialog_new(Filter *filter, gboolean show_account);
+gint ui_flt_manage_dialog_new(GtkWidget *widget, Filter *filter, gboolean show_account);
 
 
 #endif
